This folder includes images etc. used in the main FitBenchmarking [README](../README.md). Other documentation can also be found on the FitBenchmarking [Wiki](https://github.com/fitbenchmarking/fitbenchmarking/wiki).

Furthermore, sphinx documentation is being setup within the source folder and which can be build with Makefile and make.bat. Also this docs is linked up with [Read the Docs](https://readthedocs.org/) and the automatically build sphinx is viewable from https://fitbenchmarking.readthedocs.io
